@@ -37,14 +37,15 @@ protected:
     }
 };
 
-DetailWindow::DetailWindow(Target * _target, const QString & groupName, bool istemplate, bool edit, eWallet *paTarget, QWidget *parent) :
+DetailWindow::DetailWindow(Target * _target, const QString & groupName, int istemplate, bool edit, eWallet *paTarget, QWidget *parent) :
 		QMainWindow(parent)
 {
 	this->setAttribute(Qt::WA_Maemo5StackedWindow);
 	if (!edit)
 		connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged(int)));
 
-	isNew = istemplate || _target == NULL;
+	isNew = istemplate > 0 || _target == NULL;
+	typeChanged = false;
 
 	this->target = _target;
 	this->parent = paTarget;
@@ -52,19 +53,25 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, bool ist
 
 	qDebug () << "DETAIL " << target << " " << groupName << " " << istemplate << " " << edit;
 
-	if (istemplate) {
+	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
+
+	if (istemplate > 0) {
 		this->target = new Target ();
+		if (istemplate > 1) {
+			this->target->name = "Copy of ";
+			this->target->name.append (_target->name);
+		}
 		this->target->type = _target->type;
 		this->target->groupName = _target->groupName;
 
 		for (int i = 0; i < _target->fields.size(); i++) {
 			TargetField * tmp = _target->fields.at(i);
 
-			//if (!target->existField (tmp.name)) {
-				TargetField * f=  new TargetField (tmp->name, tmp->type, tmp->encrypted, tmp->order);
-
-				this->target->fields.append(f);
-			//}
+			TargetField * f=  new TargetField (tmp->name, tmp->type, tmp->encrypted, tmp->order);
+			this->target->fields.append(f);
+			if (istemplate > 1) {
+				f->value = tmp->value;
+			}
 		}
 
 		_target->freeFieldList();
@@ -87,7 +94,7 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, bool ist
 	currentImageN = NULL;
 	currentImageBackN = NULL;
 
-	if (_target && !istemplate) {
+	if (_target && istemplate == 0) {
 		currentImage = this->target->getPicture();
 		currentImageBack = this->target->getPictureBack();
 	}
@@ -114,6 +121,8 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, bool ist
 	else {
 		menuBar()->addAction("New", this, SLOT(_newTarget()));
 		menuBar()->addAction("Edit", this, SLOT(_editTarget()));
+		menuBar()->addAction("New like this", this, SLOT(_newLikeTarget()));
+		menuBar()->addAction("Duplicate", this, SLOT(_duplicateTarget()));
 		menuBar()->addAction("Export Face Pict.", this, SLOT(exportCardFace()));
 		menuBar()->addAction("Export Back Pict.", this, SLOT(exportCardBack()));
 	}
@@ -148,7 +157,7 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, bool ist
 	    nameLineEdit = new QLineEdit(this);
 		componentLayout->addWidget(nameLineEdit, 1, 3, 1, 4);
 
-			nameLineEdit->setText (this->target->name);
+		nameLineEdit->setText (this->target->name);
 
 		nameLabel = new QLabel("Group Name", this);
 		componentLayout->addWidget(nameLabel, 2, 1, 1, 2);
@@ -156,7 +165,7 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, bool ist
 	    groupLineEdit = new QLineEdit(this);
 		componentLayout->addWidget(groupLineEdit, 2, 3, 1, 4);
 
-			groupLineEdit->setText (this->target->groupName);
+		groupLineEdit->setText (this->target->groupName);
 	}
 	else {
 		this->setWindowTitle (_target->name);
@@ -174,10 +183,10 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, bool ist
 		for(int i = 0; i < this->parent->types->size(); i++) {
 			typeLineEdit->addItem (this->parent->types->at(i), this->parent->types->at(i));
 
-				if (this->target->type == this->parent->types->at(i)) {
-					typeLineEdit->setCurrentIndex(i);
-					selected = true;
-				}
+			if (this->target->type == this->parent->types->at(i)) {
+				typeLineEdit->setCurrentIndex(i);
+				selected = true;
+			}
 		}
 		if (!selected) {
 			typeLineEdit->setCurrentIndex(this->parent->types->size() - 1);
@@ -282,6 +291,8 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, bool ist
 
 	vboxlayout->addLayout(componentLayout);
 
+	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
+
 	orientationChanged(0);
 }
 
@@ -485,6 +496,7 @@ void DetailWindow::clickPass (QWidget * _wid) {
 }
 
 void DetailWindow::changeFields (int a) {
+	typeChanged = true;
 
 	qDebug () << "selected type " << a;
 
@@ -546,6 +558,8 @@ void DetailWindow::saveTarget () {
 		return;
 	}
 	
+	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
+
 	if (target == NULL) {
 		this->target = new Target ();
 	}
@@ -618,14 +632,21 @@ void DetailWindow::saveTarget () {
 	if (currentImageN) delete currentImageN;
 
 	qDebug () << "clse ";
+
+	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
+
 	close();
 }
 
 void DetailWindow::_deleteTarget () {
+	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
+
 	if (target) {
 		parent->deleteTarget(target);
 	}
 
+	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
+
 	close();
 }
 
@@ -635,6 +656,17 @@ void DetailWindow::_editTarget () {
 	close ();
 }
 
+void DetailWindow::_newLikeTarget () {
+	emit newLikeTarget(target);
+
+	close ();
+}
+void DetailWindow::_duplicateTarget () {
+	emit duplicateTarget(target);
+
+	close ();
+}
+
 void DetailWindow::_newTarget () {
 
 	emit newTarget();
@@ -851,6 +883,7 @@ void DetailWindow::exportCardBack()
 		}
 	}
 }
+
 void DetailWindow::cardBack()
 {
 	QString path(QDesktopServices::storageLocation(QDesktopServices::PicturesLocation));
@@ -872,6 +905,46 @@ void DetailWindow::cardBack()
 	}
 }
 
+void DetailWindow::closeEvent(QCloseEvent *event) {
+	qDebug () << "close event";
+	if (edit || isNew) {
+		bool isModified = false;
+
+		isModified |= typeChanged || nameLineEdit->isModified() || groupLineEdit->isModified();
+
+		for (int i = 0; (!isModified) && (i < target->fields.count()); i++) {
+			TargetField * field = target->fields[i];
+			if (field->type == TYPE_TEXT) {
+				qDebug () << "getting TEX field " << i;
+				isModified |= ((QTextEdit*)values[i])->document ()->isModified ();
+			}
+			else {
+				qDebug () << "getting LIN field " << i;
+				isModified |= ((QLineEdit*)values[i])->isModified();
+			}
+		}
+
+		isModified |= deleteFace || currentImageN != NULL;
+		isModified |= deleteBack || currentImageBackN != NULL;
+
+		if (isModified) {
+			QMessageBox * messageBox = new QMessageBox(this);
+			int b = messageBox->information(this, "Wallet", "Are you sure you want to discard changes?", QMessageBox::Yes, QMessageBox::No);
+			if (b == QMessageBox::Yes) {
+				event->accept();
+			}
+			else {
+				event->ignore();
+			}
+			delete messageBox;
+		}
+		else
+			event->accept();
+	}
+	else
+		event->accept();
+}
+
 CreateFieldDialog::CreateFieldDialog(Target * target, DetailWindow *paTarget) :
 		QDialog((QWidget*)paTarget)
 {
