@@ -49,7 +49,7 @@ class DetailWindow: public QMainWindow
 	Q_OBJECT
 
 public:
-	DetailWindow (Target * target, const QString & groupName, bool istemplate, bool edit, eWallet *paTarget, QWidget *parent = 0);
+	DetailWindow (Target * target, const QString & groupName, int istemplate, bool edit, eWallet *paTarget, QWidget *parent = 0);
 	~DetailWindow ();
 	
 	void addField (TargetField * field);
@@ -85,10 +85,12 @@ private:
 	void changeFields (int);
 	void _addField (TargetField * field);
 
+	void closeEvent(QCloseEvent *event);
 	bool edit;
 	bool deleteFace;
 	bool deleteBack;
 	bool isNew;
+	bool typeChanged;
 
 	QGridLayout * componentLayout;
 	QPointer<CreateFieldDialog> createFieldDlg;
@@ -98,6 +100,10 @@ public slots:
 	void _deleteTarget();
 	void _editTarget();
 	void _newTarget();
+
+	void _newLikeTarget();
+	void _duplicateTarget();
+
 	void cardFace();
 	void mirrorFace();
 	void orientationChanged (int);
@@ -120,6 +126,8 @@ public slots:
 signals:
 	void newTarget();
 	void editTarget(Target * source);
+	void newLikeTarget(Target * source);
+	void duplicateTarget(Target * source);
 
 };
 
