@@ -12,6 +12,8 @@
  * TODO multilanguage
  * TODO pc version?
  * TODO fix problems with key
+ * TODO rearrange view fields (for sure TEXTFIELD)
+ * TODO bigger login buttons
  */
 
 #include "eWallet.h"
@@ -667,6 +669,8 @@ void eWallet::showInfo(bool reset) {
 
 void eWallet::showTargets(bool reset, const QString & filter)
 {
+	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
+
 	qDebug () << "show Targets " << reset;
 
 	int current = fnListWidget->currentRow();
@@ -701,6 +705,8 @@ void eWallet::showTargets(bool reset, const QString & filter)
 	fnListWidget->setCurrentRow(0);
 
 	update();
+
+	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
 }
 
 void eWallet::createMenu()
@@ -912,12 +918,13 @@ void eWallet::viewTarget(Target * rent) {
 	dbManager->getFields(rent);
 
 	if (detailWindow.isNull()) {
-		detailWindow = new DetailWindow(rent, "", false, false, this, this);
+		detailWindow = new DetailWindow(rent, "", 0, false, this, this);
+
+		connect(detailWindow, SIGNAL(editTarget(Target*)), this, SLOT(editTarget(Target*)));
+		connect(detailWindow, SIGNAL(newLikeTarget(Target*)), this, SLOT(newLikeTarget(Target*)));
+		connect(detailWindow, SIGNAL(duplicateTarget(Target*)), this, SLOT(duplicateTarget(Target*)));
+		connect(detailWindow, SIGNAL(newTarget()), this, SLOT(newTarget()));
 
-		connect(detailWindow, SIGNAL(editTarget(Target*)),
-                      this, SLOT(editTarget(Target*)));
-		connect(detailWindow, SIGNAL(newTarget()),
-                      this, SLOT(newTarget()));
         detailWindow->setAttribute(Qt::WA_DeleteOnClose);
         connect(detailWindow, SIGNAL(destroyed(QObject*)),
                 this, SLOT(windowDestroyed(QObject*)));
@@ -926,21 +933,6 @@ void eWallet::viewTarget(Target * rent) {
 	}
 }
 
-void eWallet::editTarget(Target * rent) {
-	//qDebug()<<"edit ";
-
-	dbManager->getFields(rent);
-
-	if (detailWindowEdit.isNull()) {
-		detailWindowEdit = new DetailWindow(rent, "", false, true, this, this);
-		//detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
-        detailWindowEdit->setAttribute(Qt::WA_DeleteOnClose);
-        connect(detailWindowEdit, SIGNAL(destroyed(QObject*)),
-                this, SLOT(windowDestroyedEdit(QObject*)));
-        detailWindowEdit->show();
-	}
-}
-
 void eWallet::import() {
 	QString path(QDesktopServices::storageLocation(QDesktopServices::HomeLocation));
 	QString s = QFileDialog::getOpenFileName(
@@ -1125,19 +1117,6 @@ void eWallet::import() {
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
 }
 
-void eWallet::newTarget() {
-	//qDebug()<<"new ";
-
-	if (detailWindowEdit.isNull()) {
-		detailWindowEdit = new DetailWindow(NULL, currentGroup, false, true, this, this);
-		//detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
-        detailWindowEdit->setAttribute(Qt::WA_DeleteOnClose);
-        connect(detailWindowEdit, SIGNAL(destroyed(QObject*)),
-                this, SLOT(windowDestroyedEdit(QObject*)));
-        detailWindowEdit->show();
-	}
-}
-
 void eWallet::renameGroup () {
 
 	if (fnListWidget->currentRow() > 0) {
@@ -1196,6 +1175,7 @@ void eWallet::contextMenuEvent (QContextMenuEvent * event) {
 			menu.addAction("View", this, SLOT(_viewcTarget()));
 			menu.addAction("Edit", this, SLOT(_editcTarget()));
 			menu.addAction("New like this", this, SLOT(_newLikeTarget()));
+			menu.addAction("Duplicate", this, SLOT(_duplicateTarget()));
 			menu.addAction("Delete", this, SLOT(_deletecTarget()));
 			menu.exec(event->globalPos());
 		}
@@ -1301,49 +1281,76 @@ void eWallet::exportData() {
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
 }
 
+void eWallet::editTarget(Target * target) {
+	dbManager->getFields(target);
+
+	if (detailWindowEdit.isNull()) {
+		detailWindowEdit = new DetailWindow(target, "", 0, true, this, this);
+		//detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
+        detailWindowEdit->setAttribute(Qt::WA_DeleteOnClose);
+        connect(detailWindowEdit, SIGNAL(destroyed(QObject*)),
+                this, SLOT(windowDestroyedEdit(QObject*)));
+        detailWindowEdit->show();
+	}
+}
+
+void eWallet::duplicateTarget (Target * target) {
+	dbManager->getFields(target);
+
+	if (detailWindowEdit.isNull()) {
+		detailWindowEdit = new DetailWindow(target, currentGroup, 2, true, this, this);
+		//detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
+        detailWindowEdit->setAttribute(Qt::WA_DeleteOnClose);
+        connect(detailWindowEdit, SIGNAL(destroyed(QObject*)),
+                this, SLOT(windowDestroyedEdit(QObject*)));
+        detailWindowEdit->show();
+	}
+}
+
+void eWallet::newLikeTarget (Target * target) {
+	dbManager->getFields(target);
+
+	if (detailWindowEdit.isNull()) {
+		detailWindowEdit = new DetailWindow(target, currentGroup, 1, true, this, this);
+		//detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
+        detailWindowEdit->setAttribute(Qt::WA_DeleteOnClose);
+        connect(detailWindowEdit, SIGNAL(destroyed(QObject*)),
+                this, SLOT(windowDestroyedEdit(QObject*)));
+        detailWindowEdit->show();
+	}
+}
+
+void eWallet::newTarget() {
+	if (detailWindowEdit.isNull()) {
+		detailWindowEdit = new DetailWindow(NULL, currentGroup, 0, true, this, this);
+		//detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
+        detailWindowEdit->setAttribute(Qt::WA_DeleteOnClose);
+        connect(detailWindowEdit, SIGNAL(destroyed(QObject*)),
+                this, SLOT(windowDestroyedEdit(QObject*)));
+        detailWindowEdit->show();
+	}
+}
+
+
 void eWallet::_newLikeTarget() {
 	if (fnListWidget->currentRow() >= 0) {
 		Target * target = list.at(fnListWidget->currentRow());
+		newLikeTarget (target);
+	}
+}
 
-		dbManager->getFields(target);
-
-		if (detailWindowEdit.isNull()) {
-			detailWindowEdit = new DetailWindow(target, currentGroup, true, true, this, this);
-			//detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
-	        detailWindowEdit->setAttribute(Qt::WA_DeleteOnClose);
-	        connect(detailWindowEdit, SIGNAL(destroyed(QObject*)),
-	                this, SLOT(windowDestroyedEdit(QObject*)));
-	        detailWindowEdit->show();
-		}
+void eWallet::_duplicateTarget() {
+	if (fnListWidget->currentRow() >= 0) {
+		Target * target = list.at(fnListWidget->currentRow());
+		duplicateTarget (target);
 	}
 }
 
 void eWallet::_editcTarget() {
-//	if (isShowGroups == 1) {
-//		if (fnListWidget->currentRow() > 0) {
-//			QString target = grouplist.at(fnListWidget->currentRow() - 1);
-//
-//			RenameGroupDialog * dialog = new RenameGroupDialog (this);
-//			dialog->setName(target);
-//			dialog->exec();
-//			QString newName = dialog->getName();
-//
-//			qDebug () << "NEW GROUP NAME " << target << " TO " << newName;
-//
-//			delete dialog;
-//
-//			if (::dbManager->renameGroup(target, newName)) {
-//				showGroups(true);
-//			}
-//
-//		}
-//	}
-//	else {
-		if (fnListWidget->currentRow() >= 0) {
-			Target * target = list.at(fnListWidget->currentRow());
-			editTarget(target);
-		}
-//	}
+	if (fnListWidget->currentRow() >= 0) {
+		Target * target = list.at(fnListWidget->currentRow());
+		editTarget(target);
+	}
 }
 void eWallet::_deletecTarget() {
 	if (fnListWidget->currentRow() >= 0) {
@@ -1359,7 +1366,6 @@ void eWallet::_viewcTarget() {
 }
 
 void eWallet::closeEvent(QCloseEvent *event){
-	//qDebug () << "close Event";
 	event->accept();
 }
 
